@@ -1,6 +1,6 @@
 """Utilities for asyncio-friendly file handling."""
 from .threadpool import open
 
-__version__ = "0.4.0"
+__version__ = "0.6.0"
 
-__all__ = (open,)
+__all__ = ["open"]
